Support requests, general questions and comments can be `sent
<mailto:diofant@googlegroups.com>`_ to the `Diofant mailing list`_.

.. _Diofant mailing list: https://groups.google.com/forum/#!forum/diofant
